@@ -391,7 +391,7 @@ lbetagpdcon <- function(x, bshape1 = 1, bshape2 = 1, u = qbeta(0.9, bshape1, bsh
     
     syu = 1 + xi * (xu - u) / sigmau  
   
-    if ((min(syu) <= 0) | (sigmau <= 0) | (du < .Machine$double.eps) | (phiu <= 0) | (phiu >= 1)) {
+    if ((min(syu) <= 0) | (sigmau <= 0) | (du < .Machine$double.eps) | (phiu <= 0) | (phiu >= 1) | (pu <= 0) | (pu >= 1)) {
       l = -Inf
     } else { 
       l = lgpd(xu, u, sigmau, xi, phiu)
@@ -442,7 +442,7 @@ nlbetagpdcon <- function(pvector, x, phiu = TRUE, finitelik = FALSE) {
 # beta bulk with GPD for upper tail with continuity at threshold
 # designed for sapply to loop over vector of thresholds (hence u is first input)
 proflubetagpdcon <- function(u, pvector, x, phiu = TRUE, method = "BFGS",
-  control = list(maxit = 10000), finitelik = FALSE, ...) {
+  control = list(maxit = 10000), finitelik = TRUE, ...) {
 
   np = 4 # maximum number of parameters
   
